# Filename:     tb_seq_mult_2_fsmd.do
# Filetype:     Modelsim Script File
# Date:         4 june 2013
# Update:       15 may 2014
# Description:  Script File For Automatic Simulation
# Author:       J. op den Brouw
# State:        Demo
# Error:        -
# Version:      1.0.2
# Copyright:    (c)2014, De Haagse Hogeschool

# This file is part of Sequential Multiplier V2.0

# Set transcript on
transcript on

# Recreate the work directory and map to work
if {[file exists rtl_work]} {
	vdel -lib rtl_work -all
}
vlib rtl_work
vmap work rtl_work

# Find out if we're started through Quartus or by hand
# (or by using an exec in the Tcl window in Quartus).
# Quartus has the annoying property that it will start
# Modelsim from a directory called "simulation/modelsim".
# The design and the testbench are located in the project
# root, so we've to compensate for that.
if [ string match "*simulation/modelsim" [pwd] ] { 
	set prefix "../../"
	puts "Running Modelsim from Quartus..."
} else {
	set prefix ""
	puts "Running Modelsim..."
}

# Compile the VHDL description and testbench,
# please note that the design and its testbench is located
# in the project root, but the simulator start in directory
# <project_root>/simulation/modelsim, so we have to compensate
# for that.
vcom -2008 -work work ${prefix}seq_mult_2.vhd
vcom -2008 -work work ${prefix}tb_seq_mult_2.vhd

# Start the simulator with 1 ns time resolution
vsim -t 1ns -L rtl_work -L work -voptargs="+acc" tb_seq_mult_2

# Log all signals in the design, good if the number
# of signals is small.
add log -r *

# Add all toplevel signals
# Add a number of signals of the simulated design
#add list *
#add list dut/current_state
#add list dut/next_state

# Add all toplevel signals
# Add a number of signals of the simulated design
add wave -divider "Inputs"
add wave -label clk clk
add wave -label areset areset
add wave -label start start
add wave -label data dataa
add wave -label data datab

add wave -divider "Debugging Internals"
add wave -label state dut/state
# Add signals if it exists
set sigs {rega regb regp loada loadb loadp clearp shifta shiftb }
foreach sig $sigs {
	if { [string length [find signals -recursive $sig]] > 0} { add wave -label $sig dut/$sig }
}

add wave -divider "Outputs"
add wave -label resultp resultp
add wave -label ready ready

# Open Structure, Signals (waveform) and List window
view structure
#view list
view signals

# Run simulation for 300 ns
run 300 ns

# Fill up the waveform in the window
wave zoom full
