-- Filename:     tb_seq_mult_2_fsmd.vhd
-- Filetype:     VHDL code testbench
-- Date:         25 may 2011
-- Update:       20 may 2014
-- Description:  Testbench the multiplier
-- Author:       J. op den Brouw
-- State:        demo
-- Error:        -
-- Version:      1.0.1
-- Copyright:    (c)2014, De Haagse Hogeschool

-- This file is part of Sequential Multiplier V2.0

-- The VHDL file contains the testbench for the
-- multiplier. The first run calculates 13x11,
-- the second run calculates 15x15 and the last
-- run calculates 15x3. The testbench generates
-- all signals necessary, including clock and reset.

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

entity tb_seq_mult_2 is
    constant n : integer := 4;
end tb_seq_mult_2;

architecture testbench of tb_seq_mult_2 is
-- The clock period and delay
constant Tperiod : time := 10 ns;
constant small_delay : time := 1 ns;
-- The signals to be monitored
signal clk : std_logic;
signal dataa : unsigned(n-1 downto 0);
signal datab : unsigned(n-1 downto 0);
signal ready : std_logic;
signal resultp : unsigned(2*n-1 downto 0);
signal areset : std_logic;
signal start : std_logic;

-- The complete multiplier as a component
component seq_mult_2
    port (
        clk : in std_logic;
		  areset : in std_logic;
        start : in std_logic;
        dataa : in unsigned(n-1 downto 0);
        datab : in unsigned(n-1 downto 0);
        resultp : out unsigned(2*n-1 downto 0);
        ready : out std_logic
    );
end component;

-- Choose one of the architectures...
--for dut : seq_mult_2_fsmd use entity work.seq_mult_2_fsmd(rtl_var);
--for dut : seq_mult_2 use entity work.seq_mult_2_fsmd(rtl_sig);

begin

    -- The multiplier
    dut : seq_mult_2
        port map ( clk => clk, areset => areset, start => start, dataa => dataa, datab => datab, ready => ready, resultp => resultp );

    -- The clock generator.
    clockgen: process is
	 begin
        clk <= '0';
        wait for Tperiod/2;
        clk <= '1';
        wait for Tperiod/2;
	 end process clockgen;

    -- The data generator, including reset
    datagen: process is
	 begin
        -- Assert reset
        start <= '0';
        areset <= '1';
        wait for 2*Tperiod;

        -- Negate reset 
        areset <= '0';
        wait for 2*Tperiod;
        wait until clk = '1';
        wait for small_delay;

        -- Multiplication of 13 times 11
        dataa <= "1101";
		  datab <= "1011";
        wait until clk = '1';
        wait for small_delay;

        start <= '1';
        wait until clk = '1';
        wait for small_delay;
        start <= '0';

        -- wait for system to finish multiplication
        wait until ready = '1';

        wait until clk = '1';
        wait until clk = '1';
        wait until clk = '1';
        wait for small_delay;
        --start <= '0';
        wait until clk = '1';
        wait for small_delay;

        -- for single run simulation, uncomment next wait
		  --wait; 

        -- Multiplication of 15 times 15
        dataa <= "1111";
		  datab <= "1111";
        wait until clk = '1';
        wait for small_delay;

        start <= '1';
        wait until clk = '1';
        wait for small_delay;
		  start <= '0';

        -- wait for system to finish multiplication
        wait until ready = '1';
        wait for small_delay;

        wait until clk = '1';
        wait for small_delay;

        -- Multiplication of 15 times 3
        dataa <= "1111";
		  datab <= "0011";
        wait until clk = '1';
        wait for small_delay;

        start <= '1';
        wait until clk = '1';
        wait for small_delay;

        -- Done
        wait;
	 end process datagen;
end testbench;
